@@ -1,6 +1,6 @@
 #! /bin/bash
 
-if [ -z "$1" ]; then
+if [[ -z "$1" ]]; then
 	echo "No file given"
 	exit 1
 fi
