@@ -1,4 +1,4 @@
-# Copyright (C) 2005 The Backup Manager Authors
+# Copyright  2005-2006 Alexis Sukrieh
 #
 # See the AUTHORS file for details.
 #
@@ -16,13 +16,15 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
-# * * *
-# Every kind of actions that are not covered by -methods.sh libraries.
-# * * * 
+#
+# Main wrapper
+#
 
 # Loop on the backup methods
-make_archives()
+function make_archives()
 {
+    debug "make_archives()"
+
     for method in $BM_ARCHIVE_METHOD
     do      
         case $method in
@@ -47,9 +49,9 @@ make_archives()
     esac
 
     # Now make sure the md5 file is okay.
-	md5file="$BM_REPOSITORY_ROOT/${BM_ARCHIVE_PREFIX}-${TODAY}.md5"
-    if [ -e $md5file ] && 
-       [ "$BM_REPOSITORY_SECURE" = "true" ]; then
+    md5file="$BM_REPOSITORY_ROOT/${BM_ARCHIVE_PREFIX}-${TODAY}.md5"
+    if [[ -e $md5file ]] && 
+       [[ "$BM_REPOSITORY_SECURE" = "true" ]]; then
         chown $BM_REPOSITORY_USER:$BM_REPOSITORY_GROUP $md5file ||
             warning "Unable to change the owner of \"\$md5file\"."
         chmod $BM_ARCHIVE_CHMOD $md5file ||
@@ -59,8 +61,10 @@ done
 }
 
 # Loop on the upload methods
-upload_files ()
+function upload_files ()
 {
+    debug "upload_files()"
+
     for method in $BM_UPLOAD_METHOD
     do            
         case $method in
@@ -68,11 +72,11 @@ upload_files ()
             bm_upload_ftp
         ;;
         ssh|SSH|scp|SCP)
-            bm_upload_ssh	    
+            bm_upload_ssh       
         ;;
-	ssh-gpg|SSH-GPG)
-	    bm_upload_ssh_gpg
-	;;
+    ssh-gpg|SSH-GPG)
+        bm_upload_ssh_gpg
+    ;;
         rsync|RSYNC)
             bm_upload_rsync
         ;;
@@ -94,8 +98,10 @@ upload_files ()
 
 # This will parse all the files contained in BM_REPOSITORY_ROOT
 # and will clean them up. Using clean_directory() and clean_file().
-clean_repositories()
+function clean_repositories()
 {
+    debug "clean_repositories"
+
     info "Cleaning \$BM_REPOSITORY_ROOT"
     clean_directory $BM_REPOSITORY_ROOT
 }
@@ -104,9 +110,11 @@ clean_repositories()
 # This will run the pre-command given.
 # If this command prints on STDOUT "false", 
 # backup-manager will stop here.
-exec_pre_command()
+function exec_pre_command()
 {
-    if [ ! -z "$BM_PRE_BACKUP_COMMAND" ]; then
+    debug "exec_pre_command()"
+
+    if [[ ! -z "$BM_PRE_BACKUP_COMMAND" ]]; then
         info "Running pre-command: \$BM_PRE_BACKUP_COMMAND."
         RET=`$BM_PRE_BACKUP_COMMAND` || RET="false" 
         case "$RET" in
@@ -123,9 +131,11 @@ exec_pre_command()
 
 }
 
-exec_post_command()
+function exec_post_command()
 {
-    if [ ! -z "$BM_POST_BACKUP_COMMAND" ]; then
+    debug "exec_post_command()"
+
+    if [[ ! -z "$BM_POST_BACKUP_COMMAND" ]]; then
         info "Running post-command: \$BM_POST_BACKUP_COMMAND"
         RET=`$BM_POST_BACKUP_COMMAND` || RET="false"
         case "$RET" in
@@ -143,52 +153,57 @@ exec_post_command()
 
 function bm_init_env ()
 {
+    debug "bm_init_env()"
     export TOOMUCH_TIME_AGO=`date +%d --date "$BM_ARCHIVE_TTL days ago"`
     check_logger
 }
 
 function bm_init_today()
 {
+    debug "bm_init_today()"
     export TODAY=`date +%Y%m%d`                  
 }
 
 # be sure that zip is supported.
-check_filetypes()
+function check_filetypes()
 {
-	case "$BM_TARBALL_FILETYPE" in
-		"zip")
-			if [ ! -x $zip ]; then
-				error "The BM_TARBALL_FILETYPE conf key is set to \"zip\" but zip is not installed."
-			fi
-		;;
-		"tar.bz2" )
-			if [ ! -x $bzip ]; then
-				error "The BM_TARBALL_FILETYPE conf key is set to \"bzip2\" but bzip2 is not installed."
-			fi
-		;;
-		"dar" )
-			if [ ! -x $dar ]; then
-				error "The BM_TARBALL_FILETYPE conf key is set to \"dar\" but dar is not installed."
-			fi
-		;;
-	esac
+    debug "check_filetypes()"
+
+    case "$BM_TARBALL_FILETYPE" in
+        "zip")
+            if [[ ! -x "$zip" ]]; then
+                error "The BM_TARBALL_FILETYPE conf key is set to \"zip\" but zip is not installed."
+            fi
+        ;;
+        "tar.bz2" )
+            if [[ ! -x "$bzip" ]]; then
+                error "The BM_TARBALL_FILETYPE conf key is set to \"bzip2\" but bzip2 is not installed."
+            fi
+        ;;
+        "dar" )
+            if [[ ! -x "$dar" ]]; then
+                error "The BM_TARBALL_FILETYPE conf key is set to \"dar\" but dar is not installed."
+            fi
+        ;;
+    esac
 }
 
 function create_directories()
 {
-	if [ ! -d $BM_REPOSITORY_ROOT ]
-	then
-		info "The repository \$BM_REPOSITORY_ROOT does not exist, creating it."
-		mkdir $BM_REPOSITORY_ROOT
-	fi
+    debug "create_directories()"
 
-	# for security reason, the repository should not be world readable
-	# only BM_REPOSITORY_USER:BM_REPOSITORY_GROUP can read/write it. 
-	if [ "$BM_REPOSITORY_SECURE" = "true" ]; then
-		chown $BM_REPOSITORY_USER:$BM_REPOSITORY_GROUP $BM_REPOSITORY_ROOT
-		chmod $BM_REPOSITORY_CHMOD $BM_REPOSITORY_ROOT
-	fi
+    if [[ ! -d $BM_REPOSITORY_ROOT ]]
+    then
+        info "The repository \$BM_REPOSITORY_ROOT does not exist, creating it."
+        mkdir $BM_REPOSITORY_ROOT
+    fi
+
+    # for security reason, the repository should not be world readable
+    # only BM_REPOSITORY_USER:BM_REPOSITORY_GROUP can read/write it. 
+    if [[ "$BM_REPOSITORY_SECURE" = "true" ]]; then
+        chown $BM_REPOSITORY_USER:$BM_REPOSITORY_GROUP $BM_REPOSITORY_ROOT
+        chmod $BM_REPOSITORY_CHMOD $BM_REPOSITORY_ROOT
+    fi
 }
 
 
-
