@@ -1,4 +1,4 @@
-# Copyright (C) 2005-2006 The Backup Manager Authors
+# Copyright  2005-2006 Alexis Sukrieh
 #
 # See the AUTHORS file for details.
 #
@@ -16,20 +16,20 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 #
-# * * *
+
 #
-# Burning related functions. Every burning method is implemented there.
+# CD/DVD discs burning features
 #
-# * * *
 
 
 function bm_safe_unmount
 {
     device="$1"
+    debug "bm_safe_unmount($device)"
+
     realdevice=$(ls -l $device | awk '{print $10}')
-    if [ -n "$realdevice" ]; then
+    if [[ -n "$realdevice" ]]; then
         device="$realdevice"
-        __debug "device : $realdevice"
     fi
 
     for m in `grep $device /etc/mtab 2>/dev/null| awk '{print $2}'`
@@ -44,17 +44,18 @@ function bm_safe_unmount
 # This will get all the md5 sums of the day,
 # mount the BM_BURNING_DEVICE on /tmp/device and check 
 # that the files are correct with md5 tests.
-check_cdrom_md5_sums()
+function check_cdrom_md5_sums()
 {
-    has_error=0
+    debug "check_cdrom_md5_sums()"
 
-    if [ -z $BM_BURNING_DEVICE ]; then
+    has_error=0
+    if [[ -z $BM_BURNING_DEVICE ]]; then
         error "MD5 checkup is only performed on disks. Please set the BM_BURNING_DEVICE in \$conffile"
     fi
 
     # first create the mount point
-    mount_point="$(mktemp -d /tmp/bm-mnt.XXXXXX)"
-    if [ ! -d $mount_point ]; then
+    mount_point="$(mktemp -d ${BM_TEMP_DIR}/bm-mnt.XXXXXX)"
+    if [[ ! -d $mount_point ]]; then
         error "The mount point \$mount_point is not there."
     fi
     
@@ -73,14 +74,14 @@ check_cdrom_md5_sums()
         date_of_file=$(get_date_from_file $file)
         prefix_of_file=$(get_prefix_from_file $file)
 
-	# Doesn't check the md5 sum of the md5sum file...
-	if [ "$base_file" = "${prefix_of_file}-${date_of_file}.md5" ] ; then
-		continue
-	fi
+    # Doesn't check the md5 sum of the md5sum file...
+    if [[ "$base_file" = "${prefix_of_file}-${date_of_file}.md5" ]] ; then
+        continue
+    fi
 
 
        # Which file should contain the MD5 hashes for that file ?
-       if [ "$prefix_of_file" != "index" ]; then
+       if [[ "$prefix_of_file" != "index" ]]; then
            md5_file="$BM_REPOSITORY_ROOT/${prefix_of_file}-${date_of_file}.md5"
        else
            md5_file="$BM_REPOSITORY_ROOT/$BM_ARCHIVE_PREFIX-${date_of_file}.md5"
@@ -89,7 +90,7 @@ check_cdrom_md5_sums()
        str=$(echo_translated "Checking MD5 sum for \$base_file:")
 
         # if it does not exist, we create it (that will take much time).
-        if [ ! -f $md5_file ]; then
+        if [[ ! -f $md5_file ]]; then
             save_md5_sum $file $md5_file || continue
         fi
         
@@ -97,7 +98,7 @@ check_cdrom_md5_sums()
         md5hash_trust=$(get_md5sum_from_file ${base_file} $md5_file)
 
         # If the MD5 hash was not found, generate it and save it now.
-        if [ -z "$md5hash_trust" ]; then
+        if [[ -z "$md5hash_trust" ]]; then
             save_md5_sum $file $md5_file || continue
             md5hash_trust=$(get_md5sum_from_file ${base_file} $md5_file)
         fi
@@ -118,7 +119,7 @@ check_cdrom_md5_sums()
         esac
     done
 
-    if [ $has_error = 1 ]; then
+    if [[ $has_error = 1 ]]; then
         warning "Errors encountered during MD5 checks."
     fi
 
@@ -137,10 +138,12 @@ check_cdrom_md5_sums()
 # Two cases are possible:
 # - non-interactive mode: will try to burn data on a signle disc
 # - interactive mode : will ask for next disc if needed.
-burn_files()
+function burn_files()
 {
-    if [ "$BM_BURNING_METHOD" = "none" ] || 
-       [ -z "$BM_BURNING_METHOD" ]; then
+    debug "burn_files()"
+
+    if [[ "$BM_BURNING_METHOD" = "none" ]] || 
+       [[ -z "$BM_BURNING_METHOD" ]]; then
         info "No burning method used."
         return 0
     fi
@@ -148,8 +151,10 @@ burn_files()
     # Choose which mode to use (interactive or not)
     # according to the standard input
     if tty -s ; then 
+        debug "tty detected, using the interactive mode"
         burn_files_interactive
     else
+        debug "no tty detected, non-interactive mode"
         burn_files_non_interactive
     fi
 }
@@ -157,10 +162,12 @@ burn_files()
 function find_what_to_burn()
 {
     source="$1"
+    debug "find_what_to_burn($source)"
+    
     what_to_burn=""
 
     nb_file=$(ls -l $source 2>/dev/null | wc -l)
-    if [ $nb_file -gt 0 ]; then
+    if [[ $nb_file -gt 0 ]]; then
         info "Number of files to burn: \$nb_file."
     else
         error "Nothing to burn for the \$BM__BURNING_DATE, try the '--burn <date>' switch."
@@ -168,7 +175,7 @@ function find_what_to_burn()
     
     for file in $source
     do
-        if [ ! -L $file ]; then
+        if [[ ! -L $file ]]; then
             what_to_burn="$what_to_burn $file"
         fi
     done    
@@ -177,29 +184,31 @@ function find_what_to_burn()
 # This has to do something without any interactive input.
 function burn_files_non_interactive()
 {
+    debug "burn_files_non_interactive()"
+
     # find what to burn according to the size...
     what_to_burn=""
     size=$(size_of_path "$BM_REPOSITORY_ROOT")
 
     # We can't burn the whole repository, using only today's archives
-    if [ $size -gt $BM_BURNING_MAXSIZE ] || 
-       [ -n "${BM__BURNING_DATE}" ]; then
+    if [[ $size -gt $BM_BURNING_MAXSIZE ]] || 
+       [[ -n "${BM__BURNING_DATE}" ]]; then
         
-        if [ -z "$BM__BURNING_DATE" ]; then
+        if [[ -z "$BM__BURNING_DATE" ]]; then
             BM__BURNING_DATE="$TODAY"
         fi
 
-		BM__BURNING_DATE="$TODAY"
+        BM__BURNING_DATE="$TODAY"
         info "Burning archives of \$BM__BURNING_DATE."
         size=$(size_of_path "${BM_REPOSITORY_ROOT}/*${BM__BURNING_DATE}*")
         
         # does not fit neither, cannot burn anything.
-        if [ $size -gt $BM_BURNING_MAXSIZE ]; then
+        if [[ $size -gt $BM_BURNING_MAXSIZE ]]; then
             error "Cannot burn archives of the \$BM__BURNING_DATE, too big: \${size}M, must fit in \$BM_BURNING_MAXSIZE"
         fi
         find_what_to_burn "${BM_REPOSITORY_ROOT}/*${BM__BURNING_DATE}*"
     else
-		BM__BURNING_DATE="$TODAY"
+        BM__BURNING_DATE="$TODAY"
         find_what_to_burn "${BM_REPOSITORY_ROOT}/*"
     fi
 
@@ -211,17 +220,19 @@ function burn_files_non_interactive()
 # (anyway, we rely on this assertion, this should be documented).
 function burn_files_interactive()
 {
+    debug "burn_files_interactive()"
+
     purge_indexes
- 	if [ ! -z "${BM__BURNING_DATE}" ] ; then
-		info "Burning archives of \$BM__BURNING_DATE."
-		find_what_to_burn "${BM_REPOSITORY_ROOT}/*${BM__BURNING_DATE}*"
-		size=$(size_of_path "${BM_REPOSITORY_ROOT}/*${BM__BURNING_DATE}*")
+    if [[ ! -z "${BM__BURNING_DATE}" ]] ; then
+        info "Burning archives of \$BM__BURNING_DATE."
+        find_what_to_burn "${BM_REPOSITORY_ROOT}/*${BM__BURNING_DATE}*"
+        size=$(size_of_path "${BM_REPOSITORY_ROOT}/*${BM__BURNING_DATE}*")
     else
-		info "Burning the whole archives."
-		BM__BURNING_DATE="$TODAY"
-		find_what_to_burn "${BM_REPOSITORY_ROOT}/*"
-		size=$(size_of_path "${BM_REPOSITORY_ROOT}")
-	fi
+        info "Burning the whole archives."
+        BM__BURNING_DATE="$TODAY"
+        find_what_to_burn "${BM_REPOSITORY_ROOT}/*"
+        size=$(size_of_path "${BM_REPOSITORY_ROOT}")
+    fi
     info "Trying to burn \$BM_REPOSITORY_ROOT (\$size MB) in interactive mode."
     burn_multiples_media "$what_to_burn"
 }
@@ -233,15 +244,16 @@ function burn_session()
     what_to_burn="$1"
     session_number="$2"
     number_of_indexes="$3"
+    debug "burn_session($what_to_burn, $session_number, $number_of_indexes)"
 
     # Since version 0.7.5 disc-image can be non-joliet.
     # This is handled by $BM_BURNING_ISO_FLAGS, let's default that 
     # variable for backward compat.
-    if [ -z "$BM_BURNING_ISO_FLAGS" ]; then
+    if [[ -z "$BM_BURNING_ISO_FLAGS" ]]; then
         BM_BURNING_ISO_FLAGS="-R -J"
     fi
 
-    if [ -z "$session_number" ] || [ $session_number = 1 ]; then
+    if [[ -z "$session_number" ]] || [[ $session_number = 1 ]]; then
         title="Backups of ${BM__BURNING_DATE}"
     else
         title="Backups of ${BM__BURNING_DATE} - $session_number/$number_of_indexes"
@@ -251,12 +263,12 @@ function burn_session()
     bm_safe_unmount $BM_BURNING_DEVICE
     
     # get a log file in a secure path
-    logfile="$(mktemp /tmp/bm-burning.log.XXXXXX)"
+    logfile="$(mktemp ${BM_TEMP_DIR}/bm-burning.log.XXXXXX)"
     info "Redirecting burning logs into \$logfile"
     
     # set the cdrecord command 
     devforced=""
-    if [ -n "$BM_BURNING_DEVFORCED" ]; then
+    if [[ -n "$BM_BURNING_DEVFORCED" ]]; then
         info "Forcing dev=\${BM_BURNING_DEVFORCED} for cdrecord commands."
         devforced="dev=${BM_BURNING_DEVFORCED}"
     fi
@@ -264,53 +276,63 @@ function burn_session()
     # burning the iso with the user choosen method
     case "$BM_BURNING_METHOD" in
         "DVD")
-            if [ ! -x $growisofs ]; then
+            if [[ ! -x $growisofs ]]; then
                 error "DVD+R(W) burning requires \$growisofs, aborting."
             fi
             
             info "Exporting archives to the DVD+R(W) disc in \$BM_BURNING_DEVICE."
+            debug "$growisofs -use-the-force-luke=tty -Z ${BM_BURNING_DEVICE} ${BM_BURNING_ISO_FLAGS} -V \"${title}\" ${what_to_burn} >> ${logfile}"
+            tail_logfile $logfile
             $growisofs -use-the-force-luke=tty -Z ${BM_BURNING_DEVICE} ${BM_BURNING_ISO_FLAGS} -V "${title}" ${what_to_burn} >> ${logfile} 2>&1 ||
                 error "failed, check \$logfile"
         ;;
         
         "DVD-RW")
-            if [ ! -x $growisofs ]; then
+            if [[ ! -x $growisofs ]]; then
                 error "DVD-R(W) burning requires \$growisofs, aborting."
             fi
-            if [ ! -x $dvdrwformat ]; then
+            if [[ ! -x $dvdrwformat ]]; then
                 error "DVD-R(W) burning requires \$dvdrwformat, aborting."
             fi
             
             info "Blanking the DVD-R(W) disc in \$BM_BURNING_DEVICE"
+            debug "$dvdrwformat -blank $BM_BURNING_DEVICE > $logfile"
+            tail_logfile $logfile
             $dvdrwformat -blank $BM_BURNING_DEVICE > $logfile 2>&1 || 
                 error "Unable to blank the DVD-R(W) disc (check \$logfile)."
             
             info "Exporting archives to the DVD-R(W) disc in \$BM_BURNING_DEVICE."
+            debug "$growisofs -use-the-force-luke=tty -Z ${BM_BURNING_DEVICE} ${BM_BURNING_ISO_FLAGS} -V \"${title}\" ${what_to_burn} >> ${logfile}"
             $growisofs -use-the-force-luke=tty -Z ${BM_BURNING_DEVICE} ${BM_BURNING_ISO_FLAGS} -V "${title}" ${what_to_burn} >> ${logfile} 2>&1 ||
                 error "failed, check \$logfile"
         ;;
         
         "CDRW")
-            if [ ! -x $cdrecord ]; then
+            if [[ ! -x $cdrecord ]]; then
                 error "CD-R(W) burning requires \$cdrecord, aborting."
             fi
                         
             info "Blanking the CDRW in \$BM_BURNING_DEVICE."
+            debug "${cdrecord} -tao $devforced blank=fast > ${logfile}"
+            tail_logfile $logfile
             ${cdrecord} -tao $devforced blank=fast > ${logfile} 2>&1 ||
                 error "failed, check \$logfile"
             
             info "Burning data to \$BM_BURNING_DEVICE."
+            debug "${mkisofs} -V \"${title}\" -q ${BM_BURNING_ISO_FLAGS} ${what_to_burn} | ${cdrecord} -tao $devforced - > ${logfile}"
             ${mkisofs} -V "${title}" -q ${BM_BURNING_ISO_FLAGS} ${what_to_burn} | \
             ${cdrecord} -tao $devforced - > ${logfile} 2>&1 ||
                 error "failed, check \$logfile"
         ;;
         
         "CDR")
-            if [ ! -x $cdrecord ]; then
+            if [[ ! -x $cdrecord ]]; then
                 error "CD-R(W) burning requires \$cdrecord, aborting."
             fi
 
             info "Burning data to \$BM_BURNING_DEVICE."
+            debug "${mkisofs} -V \"${title}\" -q ${BM_BURNING_ISO_FLAGS} ${what_to_burn} | ${cdrecord} -tao $devforced - > ${logfile}"
+            tail_logfile $logfile
             ${mkisofs} -V "${title}" -q ${BM_BURNING_ISO_FLAGS} ${what_to_burn} | \
             ${cdrecord} -tao $devforced - > ${logfile} 2>&1 ||
                 error "failed, check \$logfile"
@@ -329,20 +351,23 @@ function burn_session()
     rm -f $logfile
 
     # checking the files in the CDR if wanted
-    if [ $BM_BURNING_CHKMD5 = true ]; then
+    if [[ $BM_BURNING_CHKMD5 = true ]]; then
         check_cdrom_md5_sums
     fi
 }
 
 function purge_indexes()
 {
+    debug "purge_indexes()"
+
     index_prefix=$(get_index_prefix)
-	rm -f ${index_prefix}*
+    rm -f ${index_prefix}*
 }
 
 function get_index_prefix()
 {
-	index_prefix="$BM_REPOSITORY_ROOT/index-${BM__BURNING_DATE}"
+    debug "get_index_prefix()"
+    index_prefix="$BM_REPOSITORY_ROOT/index-${BM__BURNING_DATE}"
     echo "$index_prefix"
 }
 
@@ -351,56 +376,59 @@ function get_index_prefix()
 # indexes are not included here, should be added by hand after that processing.
 function __build_indexes_from_target()
 {
-	target="$1"
+    target="$1"
+    debug "__build_indexes_from_target ($target)"
 
     indexes=""
-	medium_index=""
-	index_number=1
-	number_of_indexes=1
+    medium_index=""
+    index_number=1
+    number_of_indexes=1
     index_prefix=$(get_index_prefix)
-	index_session="$index_prefix-$index_number"
+    index_session="$index_prefix-$index_number"
 
     # Sorting by filetypes
-	target=$(ls -v $target)
+    target=$(ls -v $target)
 
-	# Write the indexes files in order to have one index file by medium.
-	# When a medium is full, we create a new one.
-	for file in ${target}
-	do
-		size_of_file=$(size_of_path "$file")
+    # Write the indexes files in order to have one index file by medium.
+    # When a medium is full, we create a new one.
+    for file in ${target}
+    do
+        if [[ ! -f $file ]]; then
+            continue
+        fi
+        size_of_file=$(size_of_path "$file")
 
-		if [ $size_of_file -gt $BM_BURNING_MAXSIZE ] ; then
-			warning "Not burning \$file because it does not fit in the disk."
-			continue
-		fi
+        if [[ $size_of_file -gt $BM_BURNING_MAXSIZE ]] ; then
+            warning "Not burning \$file because it does not fit in the disk."
+            continue
+        fi
 
-		# Addd file to the index file.
-		medium_possible_index="$medium_index $file"
-		size_of_possible_index=$(size_of_path "$medium_possible_index")
+        # Addd file to the index file.
+        medium_possible_index="$medium_index $file"
+        size_of_possible_index=$(size_of_path "$medium_possible_index")
 
-		if [ $size_of_possible_index -gt $BM_BURNING_MAXSIZE ] ; then
-			indexes="$indexes $index_session"
-			
-			number_of_indexes=$(($number_of_indexes +1))
-			index_number=$(($index_number + 1))
-			index_session="$index_prefix-$index_number"
-            #__debug "BM_BURNING_MAXSIZE is reached : new index: $index_session"
+        if [[ $size_of_possible_index -gt $BM_BURNING_MAXSIZE ]] ; then
+            indexes="$indexes $index_session"
+            
+            number_of_indexes=$(($number_of_indexes +1))
+            index_number=$(($index_number + 1))
+            index_session="$index_prefix-$index_number"
+            echo "$file" > $index_session
             
-			echo "$file" > $index_session
-			
             medium_index="$file"
-			medium_possible_index=""
+            medium_possible_index=""
 
-		else
-			echo "$file" >> $index_session
-			medium_index="$medium_possible_index"
-		fi	
-	done
-	indexes="$indexes $index_session"
+        else
+            echo "$file" >> $index_session
+            medium_index="$medium_possible_index"
+        fi  
+    done
+    indexes="$indexes $index_session"
 }
 
 function __insert_new_medium()
 {
+    debug "__insert_new_medium()"
     bm_pause "$(translate "Please insert a new disk in \$BM_BURNING_DEVICE")"
 }
 
@@ -409,11 +437,12 @@ function __burn_session_from_file()
     index_file="$1"
     session_number="$2"
     number_of_indexes="$3"
+    debug "__burn_session_from_file ($index_file, $session_number, $number_of_indexes)"
 
-    if [ ! -e "$index_file" ]; then
+    if [[ ! -e "$index_file" ]]; then
         error "No such index file: \"\$index_file\"."
     fi
-	
+    
     what_to_burn_session=""
 
     for file in $(cat "$index_file")
@@ -422,13 +451,13 @@ function __burn_session_from_file()
     done
     
     what_to_burn="$what_to_burn_session"
-    
     burn_session "$what_to_burn_session" "$session_number" "$number_of_indexes"
-
 }
 
 function __append_index_paths_in_indexes()
 {
+    debug "__append_index_paths_in_indexes()"
+
     prefix=$(get_index_prefix)
     for index_file in $prefix*
     do    
@@ -442,6 +471,7 @@ function __append_index_paths_in_indexes()
 function burn_multiples_media()
 {
     target="$1"
+    debug "burn_multiples_media ($target)"
     
     # first purge existing indexs
     purge_indexes
@@ -450,11 +480,11 @@ function burn_multiples_media()
     # archives to put on each medium.
     __build_indexes_from_target "$target"
 
-	# Display the number of medias required by the burning systemp.
-    if [ $number_of_indexes -eq 1 ]; then
-    	info "The burning process will need one disk."
+    # Display the number of medias required by the burning systemp.
+    if [[ $number_of_indexes -eq 1 ]]; then
+        info "The burning process will need one disk."
     else 
-    	info "The burning process will need \$number_of_indexes disks."
+        info "The burning process will need \$number_of_indexes disks."
     fi        
 
     # Now that all indexes are built, list them so we can find
@@ -471,7 +501,6 @@ function burn_multiples_media()
         __burn_session_from_file "$index" "$session_number" "$number_of_indexes"
     done
 
-	# Remove all the index files.
-	rm -f $indexes
-
+    # Remove all the index files.
+    rm -f $indexes
 }
