@@ -1,4 +1,4 @@
-# Copyright (C) 2005 The Backup Manager Authors
+# Copyright  2005-2006 Alexis Sukrieh
 #
 # See the AUTHORS file for details.
 #
@@ -11,32 +11,36 @@
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
-#
-#
-# The backup-manager's files.sh library.
-#
+
 # All functions dedicated to manage the files.
-#
 
 #unmount_tmp_dir()
 #{
-#   if [ -n "$mount_point" ] && 
-#      [ -d $mount_point ] &&
-#      [ grep $mount_point /etc/mtab >/dev/null 2>&1 ]; then
+#   if [[ -n "$mount_point" ]] && 
+#      [[ -d $mount_point ]] &&
+#      [[ grep $mount_point /etc/mtab >/dev/null 2>&1 ]]; then
 #       umount "$mount_point" > /dev/null 2>&1 || error "unable to unmount \$mount_point"
 #       sleep 1
 #       rmdir "$mount_point" > /dev/null 2>&1 || error "unable to remove \$mount_point"
 #   fi
 #}
 
+
+# detect if find supports -H
+find_opt=""
+if find -H /tmp > /dev/null 2>&1 ; then
+    find_opt="-H"
+fi    
+
 # this will send the appropriate name of archive to 
 # make according to what the user choose in the conf.
-get_dir_name()
+function get_dir_name()
 {
     base="$1"
     format="$2"
+    debug "get_dir_name ($base, $format)"
 
-    if [ "$format" = "long" ]
+    if [[ "$format" = "long" ]]
     then
         # first remove the trailing slash
         base=${base%/}
@@ -46,7 +50,7 @@ get_dir_name()
         # every / by a -
         dirname=$(echo "$dirname" | sed 's/\//-/g')
         
-    elif [ "$format" = "short" ]
+    elif [[ "$format" = "short" ]]
     then
         OLDIFS=$IFS
         export IFS="/"
@@ -66,10 +70,12 @@ get_dir_name()
 # This will take a path and return the size in mega bytes
 # used on the disk.
 # Thanks to Michel Grentzinger <mic.grentz@online.fr>
-size_of_path()
+function size_of_path()
 {
     path="$1"
-    if [ -z "$path" ]; then
+    debug "size_of_path ($path)"
+
+    if [[ -z "$path" ]]; then
         error "No path given."
     fi
 
@@ -79,23 +85,27 @@ size_of_path()
 }
 
 # Thanks to Michel Grentzinger <mic.grentz@online.fr>
-size_left_of_path()
+function size_left_of_path()
 {
     path="$1"
-    if [ -z "$path" ]; then
+    debug "size_left_of_path ($path)"
+
+    if [[ -z "$path" ]]; then
         error "No path given."
     fi
 
-	left=$(df --si --block-size=1000k "$path" | tail -n 1 | awk '{print $4}')
+    left=$(df --si --block-size=1000k "$path" | tail -n 1 | awk '{print $4}')
 
     echo $left
 
 }
 
 # Will return the prefix contained in the file name
-get_prefix_from_file()
+function get_prefix_from_file()
 {
     filename="$1"
+    debug "get_prefix_from_file ($filename)"
+
     filename=$(basename $filename)
     prefix=$(echo $filename | sed -e 's/^\([^-]\+\)-.*$/\1/')
     echo $prefix
@@ -103,26 +113,30 @@ get_prefix_from_file()
 
 
 # Will return the date contained in the file name
-get_date_from_file()
+function get_date_from_file()
 {
+    debug "get_date_from_file ($1)"
     get_date_from_archive "$1"
 }
 
 # This function is here to free each lock previously enabled.
 # We have to keep in mind that lock must be done for each conffile.
 # It is not global anymore, and that's the tricky thing.
-release_lock() {
-    if [ -e $lockfile ]; then
+function release_lock() 
+{
+    debug "release_lock()"
+
+    if [[ -e $lockfile ]]; then
         # We have to remove the line which contains 
         # the conffile.
-        newfile=$(mktemp)
+        newfile=$(mktemp /tmp/bm-lock.XXXXXX)
         newcontent=""
         OLDIFS=$IFS
         IFS=$'\n'
         for line in $(cat $lockfile)
         do
             thisfile=$(echo $line | awk '{print $2}')
-            if [ ! $conffile = $thisfile ]; then
+            if [[ ! $conffile = $thisfile ]]; then
                 echo "$line" >> $newfile
             fi
         done
@@ -135,8 +149,11 @@ release_lock() {
 # backup-manager won't run.
 # Be aware that a there will be one lock for each conffile used.
 # If the PID written in the lockfile is not alive, release.
-get_lock() {
-    if [ -e $lockfile ]; then
+function get_lock() 
+{
+    debug "get_lock()"
+
+    if [[ -e $lockfile ]]; then
         
         # look if a lock exists for that conffile (eg, we must find 
         # the path of the conffile in the lockfile)
@@ -146,9 +163,9 @@ get_lock() {
         pid=`grep " $conffile " $lockfile | awk '{print $1}'`
 
         # be sure that the process is running
-        if [ ! -z $pid ]; then
+        if [[ ! -z $pid ]]; then
             real_pid=$(ps --no-headers --pid $pid |awk '{print $1}')
-            if [ -z $real_pid ]; then
+            if [[ -z $real_pid ]]; then
                 echo_translated "Removing lock for old PID, \$pid is not running."
                 release_lock
                 #unmount_tmp_dir
@@ -156,7 +173,7 @@ get_lock() {
             fi
         fi
 
-        if [ -n "$pid" ]; then
+        if [[ -n "$pid" ]]; then
             # we really must not use error or _exit here ! 
             # this is the special point were release_lock should not be called !
             echo_translated "A backup-manager process (\$pid) is already running with the conffile \$conffile"
@@ -171,7 +188,7 @@ get_lock() {
         pid=$$
         info "Getting lock for backup-manager \$pid with \$conffile"
         echo "$$ $conffile " > $lockfile
-        if [ ! -e $lockfile ]; then
+        if [[ ! -e $lockfile ]]; then
             error "failed (check the file permissions)."
             exit 1
         fi
@@ -182,6 +199,8 @@ get_lock() {
 function get_date_from_archive()
 {
     file="$1"
+    debug "get_date_from_archive ($file)"
+
     date=$(echo $file | sed -e 's/.*\(20[0-9][0-9][0-9][0-9][0-3][0-9]\).*/\1/')
     echo "$date"
 }   
@@ -192,6 +211,8 @@ function get_date_from_archive()
 function get_name_from_archive()
 {
     archive="$1"
+    debug "get_name_from_archive ($archive)"
+
     archive=$(basename "$archive")
 
     # drop the first token before a dash (the prefix)
@@ -207,10 +228,12 @@ function get_name_from_archive()
 function get_master_from_archive()
 {
     archive="$1"
+    debug "get_master_from_archive ($archive)"
+
     archive=$(basename "$archive")
     
     master=$(echo "$archive" | sed -e 's/.*\.\(master\)\..*/\1/')
-    if [ "$master" = "master" ]; then
+    if [[ "$master" = "master" ]]; then
         echo "true"
     else 
         echo "false"
@@ -229,6 +252,8 @@ function get_newer_master()
     prefix="$1"
     name="$2"
     date="$3"
+    debug "get_newer_master ($prefix, $name, $date)"
+    
     master=""
     
     for this_master in $BM_REPOSITORY_ROOT/$prefix-$name.*.master.*
@@ -236,8 +261,8 @@ function get_newer_master()
         this_date=$(get_date_from_archive "$this_master")
         
         # is this master newer than the one we are testing?
-        if [ "$this_date" -gt "$date" ]; then
-#            __debug "found this newer master : $this_master"
+        if [[ "$this_date" -gt "$date" ]]; then
+            debug "found this newer master : $this_master"
             master="$this_master"
         fi
     done
@@ -249,8 +274,9 @@ function clean_file()
 {
     file="$1"
     purge_date="$2"
+    debug "clean_file ($file, $purge_date)"
 
-    if [ ! -f "$file" ]; then
+    if [[ ! -f "$file" ]]; then
         error "\$file is not a regular file."
     fi
 
@@ -258,25 +284,24 @@ function clean_file()
     date=$(get_date_from_archive "$file")
     name=$(get_name_from_archive "$file")
     master=$(get_master_from_archive "$file")
-    
-#    __debug "parsing $file ($prefix, $date, $name, $master)"
+    debug "parsing $file ($prefix, $date, $name, $master)"
                 
     # we assume that if we find that, we have an archive
-    if [ -n "$date" ] && [ "$date" != "$(basename $file)" ] &&
-       [ -n "$prefix" ] && [ "$prefix" != "$(basename $file)" ] &&
-       [ -n "$name" ] && [ "$name" != "$(basename $file)" ]; then
+    if [[ -n "$date" ]] && [[ "$date" != "$(basename $file)" ]] &&
+       [[ -n "$prefix" ]] && [[ "$prefix" != "$(basename $file)" ]] &&
+       [[ -n "$name" ]] && [[ "$name" != "$(basename $file)" ]]; then
         
         # look if the archive is obsolete
-        if [ "$date" -lt "$purge_date" ] || 
-           [ "$date" = "$purge_date" ]; then
+        if [[ "$date" -lt "$purge_date" ]] || 
+           [[ "$date" = "$purge_date" ]]; then
            
             # if it's a master, we have to find a newer master around
-            if [ "$master" = "true" ]; then
+            if [[ "$master" = "true" ]]; then
                 master_archive=$(get_newer_master "$prefix" "$name" "$date")
                 
                 # if the master returned is not the same as the one we have, 
                 # the one we have can be deleted, because it's older.
-                if [ "$master_archive" != "$file" ]; then
+                if [[ "$master_archive" != "$file" ]]; then
                     info "Removing obsolete master backup: \"\$file\"."
                     rm -f "$file"
                 
@@ -284,7 +309,7 @@ function clean_file()
                 # incremental archive related.
                 else
                     nb_incrementals=$(ls -l $BM_REPOSITORY_ROOT/$prefix-$name.*.* | wc -l)
-                    if [ "$nb_incrementals" = "1" ]; then
+                    if [[ "$nb_incrementals" = "1" ]]; then
                         info "Removing obsolete master backup (isolated): \"\$file\"."
                         rm -f $file
                     fi
@@ -306,28 +331,32 @@ function clean_file()
 # the file's date to the date_to_remove.
 # If the file's date is older than the date_to_remove
 # we drop the file.
-clean_directory()
+function clean_directory()
 {
     directory="$1"
+    debug "clean_directory ($directory)"
+
     purge_date=$(date +%Y%m%d --date "$BM_ARCHIVE_TTL days ago")
 
-    if [ ! -d $directory ]; then
+    if [[ ! -d $directory ]]; then
         error "Directory given was not found."
     fi
 
-    if [ "$BM_REPOSITORY_RECURSIVEPURGE" = "true" ]; then
-	maxdepth=""
+    if [[ "$BM_REPOSITORY_RECURSIVEPURGE" = "true" ]]; then
+        maxdepth=""
     else
-	maxdepth="-maxdepth 1"
+        maxdepth="-maxdepth 1"
     fi
 
     # First list all the files to process
     # and ask backup-manager-purge what to remove
-    list=$(mktemp /tmp/bm-list.XXXXXX)
-    find -H "$directory" $maxdepth \
-         -type f -print \
-         | /usr/bin/backup-manager-purge --ttl=$BM_ARCHIVE_TTL > $list
-
+    list=$(mktemp ${BM_TEMP_DIR}/bm-list.XXXXXX)
+    
+    # files & symlinks
+    find $find_opt "$directory" $maxdepth \
+         \( -type f -o -type l \) -print \
+         | $bmp --ttl=$BM_ARCHIVE_TTL > $list
+    
     # Then actually remove the files
     for archive in `cat $list`
     do
@@ -341,30 +370,32 @@ clean_directory()
 # It will look at every archives of the same source
 # and will replace duplicates (same size) by symlinks.
 # CONDITION: BM_ARCHIVE_PURGEDUPS = true
-purge_duplicate_archives()
+function purge_duplicate_archives()
 {
     file_to_create="$1"
+    debug "purge_duplicate_archives ($file_to_create)"
+
     md5hash=$(get_md5sum $file_to_create)
 
     # Only purge if BM_ARCHIVE_PURGEDUPS = true
-    if [ -z "$BM_ARCHIVE_PURGEDUPS" ] ||
-       [ "$BM_ARCHIVE_PURGEDUPS" != "true" ]; then
+    if [[ -z "$BM_ARCHIVE_PURGEDUPS" ]] ||
+       [[ "$BM_ARCHIVE_PURGEDUPS" != "true" ]]; then
         return 0
     fi
 
-    if [ ! -e $file_to_create ]; then
+    if [[ ! -e $file_to_create ]]; then
         error "The given file does not exist: \$file_to_create"
         return 1
     fi    
 
-    if [ -z "$file_to_create" ]; then
+    if [[ -z "$file_to_create" ]]; then
         error "No file given."
     fi
 
     # we'll parse all the files of the same source
     date_of_file=$(get_date_from_file $file_to_create) || 
         error "Unable to get date from file."
-    if [ -z "$date_of_file" ]; then
+    if [[ -z "$date_of_file" ]]; then
         error "Unable to get date from file."
     fi
    
@@ -375,7 +406,7 @@ purge_duplicate_archives()
     for file in $file_pattern
     do
         # handle only regular files
-        if [ ! -L $file ] && [ "$file" != "$file_to_create" ]; then
+        if [[ ! -L $file ]] && [[ "$file" != "$file_to_create" ]]; then
             
             # get the date of the file we parse
             date_of_file=$(get_date_from_file $file) || 
@@ -384,13 +415,13 @@ purge_duplicate_archives()
             # get the md5 hash of the file we parse, in its .md5 file
             md5file="$BM_REPOSITORY_ROOT/${BM_ARCHIVE_PREFIX}-${date_of_file}.md5"
             md5sum_to_check="$(get_md5sum_from_file $file $md5file)"
-            if [ -z "$md5sum_to_check" ]; then
+            if [[ -z "$md5sum_to_check" ]]; then
                 warning "Unable to find the md5 hash of file \"\$file\" in file \"\$md5file\"."
                 continue
             fi
             
             # if the md5 hashes are the same, purge the duplicate 
-            if [ "$md5hash" = "$md5sum_to_check" ]; then
+            if [[ "$md5hash" = "$md5sum_to_check" ]]; then
                 info "\$file is a duplicate of \$file_to_create (using symlink)."
                 rm -f $file
                 ln -s $file_to_create $file
