@@ -24,18 +24,18 @@ export TEXTDOMAIN
 # variable prensent in the string.
 translate()
 {
-	eval_gettext "$1"; echo
+    eval_gettext "$1"; echo
 }
 
 # This can do an echo with -n or not, and after 
 # having gettextized the string.
 echo_translated()
 {
-	if [ "$1" = "-n" ]; then
-		message=$(translate "$2")
-		echo -n "$message"
-	else
-		message=$(translate "$1")
-		echo "$message"
-	fi
+    if [[ "$1" = "-n" ]]; then
+        message=$(translate "$2")
+        echo -n "$message"
+    else
+        message=$(translate "$1")
+        echo "$message"
+    fi
 }
