@@ -23,7 +23,7 @@ source $locallib/sanitize.sh
 
 # The test actions
 
-if [ -e $BM_ARCHIVE_ROOT ]; then
+if [[ -e $BM_ARCHIVE_ROOT ]]; then
     rm -f $BM_ARCHIVE_ROOT/*
 fi    
 
@@ -42,7 +42,7 @@ err_code=0
 for dir in $subdirs_to_create
 do
     name=$(get_dir_name $dir long)
-    if [ ! -e "$BM_ARCHIVE_ROOT/$BM_ARCHIVE_PREFIX$name.$TODAY.master.tar.gz" ]; then
+    if [[ ! -e "$BM_ARCHIVE_ROOT/$BM_ARCHIVE_PREFIX$name.$TODAY.master.tar.gz" ]]; then
         err_code=$(($err_code + 1))
         echo "ERR: $BM_ARCHIVE_ROOT/$BM_ARCHIVE_PREFIX-$name.$TODAY.master.tar.gz"
     fi        
